@@ -1,10 +1,10 @@
-from geopytool.ImportDependence import *
-from geopytool.CustomClass import *
+from ImportDependence import *
+from CustomClass import *
 
 class TraceNew(AppForm):
     xticks = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
               30, 31, 32, 33, 34, 35, 36, 37]
-    xticklabels = [u'Cs', u'Tl', u'Rb', u'Ba', u'W', u'Th', u'U', u'Nb', u'Ta', u'K', u'La', u'Ce', u'Pb', u'Pr', u'Mo',
+    xticklabels = [u'',u'Cs', u'Tl', u'Rb', u'Ba', u'W', u'Th', u'U', u'Nb', u'Ta', u'K', u'La', u'Ce', u'Pb', u'Pr', u'Mo',
                    u'Sr', u'P', u'Nd', u'F', u'Sm', u'Zr', u'Hf', u'Eu', u'Sn', u'Sb', u'Ti', u'Gd', u'Tb', u'Dy',
                    u'Li',
                    u'Y', u'Ho', u'Er', u'Tm', u'Yb', u'Lu']
@@ -515,6 +515,9 @@ class TraceNew(AppForm):
 
 
         self.axes.set_xticks(self.xticks)
+        
+        
+        self.xticklabels.append( '')  # fix blank head problem by matplotlib
         self.axes.set_xticklabels(self.xticklabels, rotation=-45, fontsize=6)
 
 
