@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 #coding:utf-8
 import os
-import setuptools
-from ImportDependence import *
-from CustomClass import *
-
+from geopytool.ImportDependence import *
+from geopytool.CustomClass import *
+try:
+    from setuptools import setup
+except ImportError:
+    from distutils.core import setup
 
 
 here = os.path.abspath(os.path.dirname(__file__))
@@ -15,10 +17,9 @@ except:
     README = 'https://github.com/GeoPyTool/GeoPyTool/blob/master/README.md'
 
 
-
-setuptools.setup(name='geopytool',
-      version=version,
-      description='a tool for daily geology related task. visit com for further information',
+setup(name='geopytool',
+      version="0.9.21.0.003",
+      description='a tool for daily geology related task. visit geopytool.com for further information',
       longdescription=README,
       author='cycleuser',
       author_email='cycleuser@cycleuser.org',
@@ -27,15 +28,13 @@ setuptools.setup(name='geopytool',
       package_data={
           'geopytool': ['*.py','*.png','*.qm','*.ttf','*.ini','*.md'],
       },
-
       include_package_data=True,
 
-
       #py_modules=['CIPW','Cluster','geopytool/CustomClass','Harker','IMP','Magic','MudStone','MultiDimension','OldCustomClass','Pearce','PlotModel','QAPF','QFL','QmFLt','REE','Rose','Stereo','TAS','TableViewer','Temp','Test','Trace','XY','XYZ','ZirconCe','cli'],
 
       #py_modules=['CustomClass'],
 
-      install_requires=[ 
+      install_requires=[
                         'cython',
                         'numpy',
                         'pandas',
@@ -47,6 +46,10 @@ setuptools.setup(name='geopytool',
                         'requests',
                         'PyQt5',
                         'scikit-image',
-                        'scikit-learn',
+                        'tensorflow',
+                        'torch',
+                        'keras',
+                        'tqdm',
+                        'gym',
                          ],
      )
\ No newline at end of file
